@@ -1,12 +1,12 @@
 package MooX::Purple::G;
 
 use 5.006;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 use PPR;
 use strict;
 use warnings;
 
-my $gattrs = '(
+my $GATTRS = '(
 	allow (?&PerlNWS)
 		(?:(?!qw)(?&PerlQualifiedIdentifier)|
 		(?&PerlList))
@@ -40,17 +40,17 @@ sub import {
 	close FH;
 	while ($source =~ m/(?<match> role\s*
 		(?<class> (?&PerlIdentifier)) 
-		(?<attrs> (?: $gattrs*))
+		(?<attrs> (?: $GATTRS*))
 		(?<block> (?&PerlBlock)))
 		$PPR::GRAMMAR
 	/xms) {
 		my %hack = %+;
 		$source =~ s/$hack{match}/roles(%hack)/e;
 	}
-
+	
 	while ($source =~ m/(?<match> class\s*
 		(?<class> (?&PerlIdentifier))
-		(?<attrs> (?: $gattrs*))
+		(?<attrs> (?: $GATTRS*))
 		(?<block> (?&PerlBlock)))
 		$PPR::GRAMMAR
 	/xms) {
@@ -81,7 +81,8 @@ sub import {
 		$source =~ s/$hack{match}/public(%hack)/e;
 	}
 	
-	$source =~ s/use MooX\:\:Purple\:\:G;//;
+	$source =~ s/use MooX\:\:Purple;\n*//;
+	$source =~ s/use MooX\:\:Purple\:\:G;\n*//;
 	my $current = [caller()]->[1];
 	$current =~ s/\.(.*)/\.pmc/;
 	open FH, '>', $current or die "cannot open file to write $!";
@@ -91,8 +92,9 @@ sub import {
 
 sub roles {
 	my %args = @_;
-	my @hack = grep {$_ && $_ !~ m/^\s*$/} $args{attrs} =~ m/(?:$gattrs) $PPR::GRAMMAR/gx;
+	my @hack = grep {$_ && $_ !~ m/^\s*$/} $args{attrs} =~ m/(?:$GATTRS) $PPR::GRAMMAR/gx;
 	my ($body, %attrs) = _set_class_role_attrs($args{block}, _parse_role_attrs(@hack));
+	$body =~ s/\s*$//;
 	my $r = qq|{
 	package $args{class};
 	use Moo::Role;
@@ -103,8 +105,9 @@ sub roles {
 
 sub classes {
 	my %args = @_;
-	my @hack = grep {$_ && $_ !~ m/^\s*$/} $args{attrs} =~ m/(?:$gattrs) $PPR::GRAMMAR/gx;
+	my @hack = grep {$_ && $_ !~ m/^\s*$/} $args{attrs} =~ m/(?:$GATTRS) $PPR::GRAMMAR/gx;
 	my ($body, %attrs) = _set_class_role_attrs($args{block}, _parse_role_attrs(@hack));
+	$body =~ s/\s*$//;
 	return qq|{
 	package $args{class};
 	use Moo;
@@ -120,8 +123,8 @@ sub private {
 	my @hack = grep {$_ && $_ !~ m/^\s*$/} $args{attrs} =~ m/(?:$SATTRS) $PPR::GRAMMAR/gx;
 	my %attrs = _parse_role_attrs(@hack);
 	my $allowed = $attrs{allow} ? sprintf 'qw(%s)', join ' ', @{$attrs{allow}} : 'qw//';
-	$args{block} = '';
 	$args{block} =~ s/(^{)|(}$)//g;
+	$args{block} =~ s/^\s*//;
 	return "sub $args{method} {
 		my \$caller = caller();
 		my \@allowed = $allowed;
@@ -141,7 +144,7 @@ sub _parse_role_attrs {
 	my @roles = @_;
 	my %attrs;
 	for (@roles) {
-		while ($_ =~ m/\s*use\s*((?!qw)(?&PerlQualifiedIdentifier))\s*((?&PerlList)) $PPR::GRAMMAR/xms) {
+		if ($_ =~ m/\s*use\s*((?!qw)(?&PerlQualifiedIdentifier))\s*((?&PerlList)) $PPR::GRAMMAR/xms) {
 			push @{$attrs{use}}, sprintf "%s %s", $1, $2;
 			next;
 		}
@@ -157,9 +160,10 @@ sub _set_class_role_attrs {
 		my $allow = join ' ', @{$attrs{allow}};
 		$body =~ s{private\s*(\p{XIDS}\p{XIDC}*)}{private $1 allow qw/$allow/}g;
 	}
+
 	$attrs{is} = $attrs{is} ? sprintf "extends qw/%s/;\n", join ' ', @{$attrs{is}} : '';
 	$attrs{with} = $attrs{with} ? sprintf "with qw/%s/;\n", join ' ', @{$attrs{with}} : '';
-	$attrs{use} = $attrs{use} ? join('', map { sprintf("use %s;\n", $_) } @{$attrs{use}}) : '';
+	$attrs{use} = $attrs{use} ? join('', map { sprintf("\tuse %s;\n", $_) } @{$attrs{use}}) : '';
 	$body =~ s/(^{)|(}$)//g;
 	return $body, %attrs;
 }
@@ -170,11 +174,11 @@ __END__
 
 =head1 NAME
 
-MooX::Purple::G - MooX::Purple::G
+MooX::Purple - MooX::Purple::G
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -217,6 +221,78 @@ Version 0.06
 
 	Night->new()->five();
 
+	... writes to same/path/yourfile.pmc
+
+	{
+		package Before;
+		use Moo::Role;
+
+		sub seven { return '7' }
+	};
+
+	{
+		package World;
+		use Moo::Role;
+		with qw/Before/;
+
+		sub six {
+			my $caller = caller();
+			my @allowed = qw(Hello);
+			unless ($caller eq __PACKAGE__ || grep { $_ eq $caller } @allowed) {
+				die "cannot call private method six from $caller";
+			}
+			'six'
+		}
+	};	
+
+	{
+		package Hello;
+		use Moo;
+		use MooX::LazierAttributes;
+		use MooX::ValidateSubs;
+		with qw/World/;
+		use Scalar::Util qw/reftype/ ;
+		use JSON;
+
+		use Types::Standard qw/Str HashRef ArrayRef Object/;
+
+		attributes
+			one => [{ okay => 'one'}],
+			[qw/two three/] => [rw, Str, { default => 'the world is flat' }];
+
+		validate_subs
+			four => {
+				params => {
+					message => [Str, sub {'four'}]
+				}
+			};
+
+		sub four { return $_[1]->{message} }
+		sub five {
+			my $caller = caller();
+			my @allowed = qw(main);
+			unless ($caller eq __PACKAGE__ || grep { $_ eq $caller } @allowed) {
+				die "cannot call private method five from $caller";
+			}
+			return $_[0]->six
+		}
+		sub ten { reftype bless {}, 'Flat::World' }
+		sub eleven { encode_json { flat => "world" } }
+		1;
+	};
+
+	{
+		package Night;
+		use Moo;
+		use MooX::LazierAttributes;
+		use MooX::ValidateSubs;
+		extends qw/Hello/;
+
+		sub nine { return 'nine' }
+		1;
+	};
+
+
 =head1 AUTHOR
 
 lnation, C<< <thisusedtobeanemail at gmail.com> >>
